@@ -233,6 +233,7 @@ def generate(  # noqa: PLR0912, PLR0913, PLR0914, PLR0915
     enable_version_header: bool = False,
     allow_population_by_field_name: bool = False,
     allow_extra_fields: bool = False,
+    extra_fields: str | None = None,
     apply_default_values_for_required_fields: bool = False,
     force_optional_for_required_fields: bool = False,
     class_name: str | None = None,
@@ -428,6 +429,7 @@ def generate(  # noqa: PLR0912, PLR0913, PLR0914, PLR0915
         aliases=aliases,
         allow_population_by_field_name=allow_population_by_field_name,
         allow_extra_fields=allow_extra_fields,
+        extra_fields=extra_fields,
         apply_default_values_for_required_fields=apply_default_values_for_required_fields,
         force_optional_for_required_fields=force_optional_for_required_fields,
         class_name=class_name,
