@@ -261,6 +261,7 @@ class Config(BaseModel):
     enable_version_header: bool = False
     allow_population_by_field_name: bool = False
     allow_extra_fields: bool = False
+    extra_fields: Optional[str] = None  # noqa: UP045
     use_default: bool = False
     force_optional: bool = False
     class_name: Optional[str] = None  # noqa: UP045
@@ -475,6 +476,7 @@ def main(args: Sequence[str] | None = None) -> Exit:  # noqa: PLR0911, PLR0912,
             enable_version_header=config.enable_version_header,
             allow_population_by_field_name=config.allow_population_by_field_name,
             allow_extra_fields=config.allow_extra_fields,
+            extra_fields=config.extra_fields,
             apply_default_values_for_required_fields=config.use_default,
             force_optional_for_required_fields=config.force_optional,
             class_name=config.class_name,
