@@ -326,6 +326,7 @@ class Parser(ABC):
         allow_population_by_field_name: bool = False,
         apply_default_values_for_required_fields: bool = False,
         allow_extra_fields: bool = False,
+        extra_fields: str | None = None,
         force_optional_for_required_fields: bool = False,
         class_name: str | None = None,
         use_standard_collections: bool = False,
@@ -452,6 +453,9 @@ class Parser(ABC):
         if allow_extra_fields:
             self.extra_template_data[ALL_MODEL]["allow_extra_fields"] = True
 
+        if extra_fields:
+            self.extra_template_data[ALL_MODEL]["extra_fields"] = extra_fields
+
         if enable_faux_immutability:
             self.extra_template_data[ALL_MODEL]["allow_mutation"] = False
 
@@ -1135,7 +1139,7 @@ class Parser(ABC):
         if self.data_model_type != pydantic_model_v2.BaseModel:
             return
         for model in models:
-            if model.base_class == "Enum":
+            if "Enum" in model.base_class:
                 continue
 
             for field in model.fields:
