@@ -162,6 +162,7 @@ class OpenAPIParser(JsonSchemaParser):
         aliases: Mapping[str, str] | None = None,
         allow_population_by_field_name: bool = False,
         allow_extra_fields: bool = False,
+        extra_fields: str | None = None,
         apply_default_values_for_required_fields: bool = False,
         force_optional_for_required_fields: bool = False,
         class_name: str | None = None,
@@ -239,6 +240,7 @@ class OpenAPIParser(JsonSchemaParser):
             aliases=aliases,
             allow_population_by_field_name=allow_population_by_field_name,
             allow_extra_fields=allow_extra_fields,
+            extra_fields=extra_fields,
             apply_default_values_for_required_fields=apply_default_values_for_required_fields,
             force_optional_for_required_fields=force_optional_for_required_fields,
             class_name=class_name,
