@@ -276,3 +276,21 @@ def test_main_graphql_use_union_operator() -> None:
         ])
         assert return_code == Exit.OK
         assert output_file.read_text() == (EXPECTED_GRAPHQL_PATH / "use_union_operator.py").read_text()
+
+
+@freeze_time("2019-07-26")
+def test_main_graphql_extra_fields_allow() -> None:
+    with TemporaryDirectory() as output_dir:
+        output_file: Path = Path(output_dir) / "output.py"
+        return_code: Exit = main([
+            "--input",
+            str(GRAPHQL_DATA_PATH / "simple-star-wars.graphql"),
+            "--output",
+            str(output_file),
+            "--input-file-type",
+            "graphql",
+            "--extra-fields",
+            "allow",
+        ])
+        assert return_code == Exit.OK
+        assert output_file.read_text() == (EXPECTED_GRAPHQL_PATH / "simple_star_wars_extra_fields_allow.py").read_text()
